==> vipps_recurring_payments-8.x-1.13-alpha1.tar.gz: vipps_recurring_payments/src/Form/SettingsForm.php <==
<?php

declare(strict_types=1);

namespace Drupal\vipps_recurring_payments\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm
 *
 * @package Drupal\vipps_recurring_payments\Form
 */
class SettingsForm extends ConfigFormBase{

  public const SETTINGS = 'vipps_recurring_payments.settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vipps_recurring_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form = array_merge($form, $this->getFormCustomAttributes());

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $configFactory = $this->configFactory->getEditable(static::SETTINGS);

    foreach (array_keys($this->getFormCustomAttributes()) as $attribute) {
      $configFactory->set($attribute, $form_state->getValue($attribute));
    }

    $configFactory->save();

    parent::submitForm($form, $form_state);
  }

  private function getFormCustomAttributes():array
  {
    $config = $this->config(static::SETTINGS);

    return [
      'msn' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 10,
        '#title' => $this->t('MSN'),
        '#default_value' => $config->get('msn'),
      ],
      'access_token' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Ocp-Apim-Subscription-Key-Access-Token'),
        '#default_value' => $config->get('access_token'),
      ],
      'subscription_key' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Ocp-Apim-Subscription-Key-Ecom'),
        '#default_value' => $config->get('subscription_key'),
      ],
      'client_id' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Client id'),
        '#default_value' => $config->get('client_id'),
      ],
      'client_secret' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Client secret'),
        '#default_value' => $config->get('client_secret'),
      ],
      'base_url' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Request url'),
        '#default_value' => $config->get('base_url'),
      ],
      'merchant_redirect_url' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Merchant redirect url'),
        '#default_value' => $config->get('merchant_redirect_url'),
      ],
      'merchant_agreement_url' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Merchant redirect url'),
        '#default_value' => $config->get('merchant_agreement_url'),
      ],
      'initial_charge' => [
        '#type' => 'radios',
        '#title' => $this->t('Initial charge'),
        '#default_value' => $config->get('initial_charge') ?? 1,
        '#options' => [
          0 => $this->t('Off'),
          1 => $this->t('On'),
        ],
      ],
      'charge_retry_days' => [
        '#type' => 'number',
        '#required' => true,
        '#title' => $this->t('Retry days'),
        '#default_value' => $config->get('charge_retry_days') ?? 5,
      ],
      'sub_module' => [
        '#type' => 'radios',
        '#title' => $this->t('Sub module'),
        '#default_value' => $config->get('sub_module') ?? 'web_form',
        '#options' => [
          'web_form' => $this->t('Webform'),
          'commerce' => $this->t('Commerce'),
        ],
      ],
    ];
  }

}

==> vipps_recurring_payments-8.x-1.17-alpha1.tar.gz: vipps_recurring_payments/src/Form/SettingsForm.php <==
<?php

declare(strict_types=1);

namespace Drupal\vipps_recurring_payments\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class SettingsForm
 *
 * @package Drupal\vipps_recurring_payments\Form
 */
class SettingsForm extends ConfigFormBase{

  public const SETTINGS = 'vipps_recurring_payments.settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vipps_recurring_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form = array_merge($form, $this->getFormCustomAttributes());

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $configFactory = $this->configFactory->getEditable(static::SETTINGS);

    foreach (array_keys($this->getFormCustomAttributes()) as $attribute) {
      $configFactory->set($attribute, $form_state->getValue($attribute));
    }

    $configFactory->save();

    parent::submitForm($form, $form_state);
  }

  private function getFormCustomAttributes():array
  {
    $config = $this->config(static::SETTINGS);

    return [
      'msn' => [
        '#type' => 'textfield',
        '#maxlength' => 10,
        '#title' => $this->t('MSN'),
        '#default_value' => $config->get('msn'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'access_token' => [
        '#type' => 'textfield',
        '#maxlength' => 64,
        '#title' => $this->t('Live Access Token'),
        '#default_value' => $config->get('access_token'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'subscription_key' => [
        '#type' => 'textfield',
        '#maxlength' => 64,
        '#title' => $this->t('Live Subscription Key'),
        '#default_value' => $config->get('subscription_key'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'client_id' => [
        '#type' => 'textfield',
        '#maxlength' => 64,
        '#title' => $this->t('Live Client ID'),
        '#default_value' => $config->get('client_id'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'client_secret' => [
        '#type' => 'textfield',
        '#maxlength' => 64,
        '#title' => $this->t('Live Secret Key'),
        '#default_value' => $config->get('client_secret'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'test_msn' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 10,
        '#title' => $this->t('Test MSN'),
        '#default_value' => $config->get('test_msn'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'test_access_token' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Test Live Access Token'),
        '#default_value' => $config->get('test_access_token'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'test_subscription_key' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Test Live Subscription Key'),
        '#default_value' => $config->get('test_subscription_key'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'test_client_id' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Test Live Client ID'),
        '#default_value' => $config->get('test_client_id'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'test_client_secret' => [
        '#type' => 'textfield',
        '#required' => true,
        '#maxlength' => 64,
        '#title' => $this->t('Test Live Secret Key'),
        '#default_value' => $config->get('test_client_secret'),
        '#description' => $this->t('Get your API keys from your Vipps developer portal.'),
      ],
      'initial_charge' => [
        '#type' => 'radios',
        '#title' => $this->t('Initial charge'),
        '#default_value' => $config->get('initial_charge') ?? 1,
        '#options' => [
          0 => $this->t('Off'),
          1 => $this->t('On'),
        ],
      ],
      'charge_retry_days' => [
        '#type' => 'number',
        '#required' => true,
        '#title' => $this->t('Retry days'),
        '#default_value' => $config->get('charge_retry_days') ?? 5,
      ],
      'sub_module' => [
        '#type' => 'radios',
        '#title' => $this->t('Sub module'),
        '#default_value' => $config->get('sub_module') ?? 'web_form',
        '#options' => [
          'web_form' => $this->t('Webform'),
          'commerce' => $this->t('Commerce'),
        ],
      ],
      'test_mode' => [
        '#type' => 'radios',
        '#title' => $this->t('Enable Test Mode'),
        '#default_value' => $config->get('test_mode') ?? true,
        '#options' => [
          true => $this->t('Yes'),
          false => $this->t('No'),
        ],
      ],
    ];
  }

}
